@@ -1,6 +1,9 @@
 package Catmandu::Store::ElasticSearch::Bag;
 
 use Catmandu::Sane;
+
+our $VERSION = '0.0306';
+
 use Moo;
 use Catmandu::Hits;
 use Catmandu::Store::ElasticSearch::Searcher;
@@ -152,7 +155,7 @@ sub search {
 
     $hits = Catmandu::Hits->new($hits);
 
-    for my $key (qw(facets suggest)) {
+    for my $key (qw(facets suggest aggregations)) {
         $hits->{$key} = $res->{$key} if exists $args{$key};
     }
 
@@ -215,10 +218,20 @@ sub normalize_query {
     }
 }
 
+sub drop {
+    my ($self) = @_;
+    $self->delete_all;
+    $self->commit;
+}
+
+1;
+
+__END__
+
+=pod
+
 =head1 SEE ALSO
 
 L<Catmandu::Bag>, L<Catmandu::Searchable>
 
 =cut
-
-1;
